bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 19. Aventiure
___________________________________________________ #### Auentv wie der Nibelunge hort ze Wormze braht wart
| ### <Do> div minnekliche also verwitewet wart ### bi ir ime lande der grave Eckewart ### beleip mit sinen mannen sin triwe im daz gebot ### er diente siner frowen mit willen vnz an sinen tot ### Ze Wormze bi dem munster ein gezimber man ir sloz ### von holze harte michel wit un– groz ### da si mit ir gesinde sit ane frevde saz ### si was zer chirchen gerne vn– tet vil willechliche daz
###### 1114 | ### Da man begrvop ir vriedel wie selten si daz lie ### mit trvrigem mvote si alle cite dar gie ### si bat got den richen der sinen sele pflegn ### vil diche wart beweinet mit grozen triwen der degn
###### 1115 | ### Vote vn– ir gesinde si trosten zaller stvnt ### do was ir daz herce so grozliche wnt ### ez chunde niht vervahen swaz man ir trostes bot ### si hete nach ir frivnde die allergrozisten not
###### 1116 | ### die nach liebem manne ie mere wip gewan ### man moht ir starche tvgende chiesen wol dar an ### si chlaget unz an ir ende die wile wert ir lip ### sit rach sich harte swinde in grozen triwen daz wip
| ### Svs saz si in ir leiden daz ist al war ### nach ir mannes tode vnz in daz vierde iar ### daz si zir brvder Gunther dehein wort nie gesprach ### un– ovch ir vint Hagenen in der zite niene gesach
###### 1118 | ### Hagene sprach zem chunige mohten wir daz tragen an ### daz ir iwer swester hulde mohtet han ### so choem zv disen landen daz Nibelunges golt ### des wrde vns vil ze teile wær uns div kuniginne holt
###### 1119 | ### Daz schuln wir versvchen sprach der kunic sa ### ich wil ez mine brveder hin ze ir werbn lan ### daz si mir daz fvegen daz si vns gerne sehe ### ine trowes niht sprach Hagene daz ez immer geschehe
###### 1120 | ### Do hiez er Ortwinen hin ze hove gan ### vn– der marchrauin Geren do daz was getan ### man braht ovch Gernoten vn– Giselher daz kint ### si versvohtenz vrivntliche an frowen Chriemh' sint
| ### Do sprach von Buregonden der chuone Gernot ### frowe ir chlaget ze lange den Sivrides tot ### nv wil der kunich iv rihten daz ers niht hat erslagen ### man hoert ivch zallen ziten so rehte groezliche klagn
###### 1122 | ### Si sprach des zihet <niemen> in [43r]in slvoch div Hagenen hant ### wa man in verhowen moehte do er daz an mir ervant ### solt ich des getrowen daz er im trvege haz ### ich hete wol behvetet sprach div kuniginne daz
###### 1123 | ### daz ich niht vermeldet hete sinen lip ### so liez ich nv min weinen ich vil armez wip ### holt wirde ich in nimmer die ez da habent getan ### do begunde <vlegen> Giselher der vil wætlich man
###### 1124 | ### Si sprach ich mvoz in grvezen irn welts mich niht erlan ### der habe groze sunde der kunic hat mir getan ### so vil der hercen swære gar ane mine scholt ### min mvnt im giht der svone im wirt daz herce nimmer holt
###### 1125 | ### Dar nach wirt ez bezzer sprachen ir mage do ### waz ob er ir an verdienet daz si noch wirdet vro ### er mac si wol ergezzen sprach Gernot der helt ### do sprach div iamersriche seht nv tvon ich swaz ir welt
| ### Si wolden kunic grvzen do si in des veriach ### mit sinen besten frivnden ers in ir hvse sach ### done torste Hagene fvr si niht gegan ### wol wesser sine schulde er het ir leide getan
###### 1127 | ### Do si verchiesen wolde vf in den grozen haz ### Gunther gezogenliche gie gegen ir dar naher baz ### durch des hordes liebe was der rat getan ### dar vmbe riet die svone der vil vngetriwe man
###### 1128 | ### Ez enwart nie svone mit so vil træhenen me ### mit valsche gefvget ir tet ir schade we ### si verchos vf si alle wan vf den einen man ### in het erslagen niemen het ez niht Hagene getan
###### 1129 | ### Dar nach uil unlange do trvgen si daz an ### daz div kuniginne den grozen hort gewan ### von Nibelunge lande vn– fvrt in an den Rin ### ez was ir morgengabe er solt ir wol von rehte sin
| ### Dar nach si beide fvren Giselher un– Gernot ### zwelf hundert mannen Chriemh' do gebot ### die in da holn solden da er verborgen lac ### da sin der degn Albrich mit sinen besten friunden pflac
###### 1131 | ### Do die uon <Rine> chomen in Nibelunge lant ### do sprach zvo sinen magen Albrich al zehant ### wir mvgn ir des hordes vor gehabn niht ### sit sin ze morgengabe div edele kuniginne giht
###### 1132 | ### Doch enwrde ez nimmer sprach Albrich getan ### niwan daz wir vbele da verlorn han ### mit dem vil edeln rechen die gvten Tarn hvot ### die trvoch von allem rehten der schonen Chriemh' trvot
###### 1133 | ### Nv ist ez leider vbele Sivride chomen ### daz vns die tarnkappen het der helt benomen ### vn– daz im mvse dienen mit vorhten dizze lant ### do gie der chamerære da er des hordes sluzzel vant
| ### Ez stvnden vor dem berge die Chriemh' man ### vn– ovch ein teil ir mage den schazze man trvge dan ### nider zv den unden an div schiffelin ### den fvrt man vf dem sewe vof ze berge vnz in den Rin
###### 1135 | ### Nv mvgt ir von dem horde wnder [43v]horn sagn ### swaz zwelf kanzwægene meiste mohten tragen ### viere tage lange von dem berge dan ### ovch mvos ir ieslicher des tages nivn stvnden gan
###### 1136 | ### Ezen was niht anders wan gesteine vn– golt ### vn– ob man die werlt alle het da von gesolt ### sine wrde nimmer minre einer marche wert ### iane hete is Hagene ane schulde niht gegert
###### 1137 | ### Der wnsch der lac dar vnder von golde ein rvrelin ### der daz het erchunnen der mohte meister sin ### wol in aller werlde vber ieslichen man ### der Albriches mage chom mit Gernote vil dan
| ### Do sich der herre Germot vn– Giselher daz chint ### des hordes underwnden do vnderwnden si sich sint ### des landes un– der burge vn– maniges rechen balt ### daz mvos in sider dienen bediv durch vorht vn– gewalt
###### 1139 | ### Do si den hort behielten in Guntheres lant ### vn– sihs div kuniginne alles underwant ### kamern vn– tvrne sin wrden vol getragn ### man gehort daz wnder von gvte mere nie gesagn
###### 1140 | ### Vn– wær sin tusint stunden noch also vil gewesn ### vn– solt der herre Sivrit gesvnder sin gewesn ### bi im wære Chriemh' hende bloz bestan ### getriwer wibes kunne ein helt nie mere noch gewan
###### 1141 | ### Do si den hort nv hete do brahtes in daz lant ### vil der vremden rechen ia gab der frowen hant ### daz man so grozer milte mere nie gesach ### si pflac vil grozer tvgende des man der kuniginne iach
###### 1142 | ### Den armen vn– den richen begunde si do geben ### daz daz reite Hagene ob si solde leben ### noch deheine wile daz si so manigen man ### ze dienste ir gewnne daz si des angest mvsen han
###### 1143 | ### Do sprach der chunic Gunther ir ist lip un– gvot ### zwiv solde ich daz wenden swaz si da mit getvot ### ich erwarbez vil chume daz si mir wart sider holt ### nvne rvchen war si teile bediv ir silber vn– ir golt
###### 1144 | ### Hagene sprach zem chunige ez ensolde ein frvmer man ### deheinem einem wibe niht <des> hordes lan ### si bringet ez mit gabe noch unz vf den tac ### daz vil wol geriwen die chvenen Burgonden mac
###### 1145 | ### Des antwrt im Gunther ich swor ir einen eit ### daz ich ir getæte nimmer mere leit ### vn– wil es furbaz hveten si ist div swester min ### do sprach aber Hagene lat mich der schuldige sin
| ### Ir svmelicher eide waren vnbehvot ### do namen si der witewen daz vil groze gvot ### Hagen sich der sluzzel aller underwant ### vil sere ez zvrnde Gernot daz er daz rehte ervant
###### 1147 | ### Do sprach der herre Giselher miner swester hat getan ### Hagene so vil der leide ich soldez understan ### vn– wær er mir niht sippe ez gienge im an den lip ### ieteniwez weinen tet do Sivrides wip
###### 1148 | ### Do sprach der [44r]herre Gernot e daz wir immer sin ### gemvet mit disem golde wir soldenz in den Rin ### allez heizen senchen daz immer wrde man ### si gie vil klageliche fver Giselher ir brvder stan
###### 1149 | ### Si sprach vil lieber bruder dv solt gedenchen min ### des libes un– des gvtes soltv min vogt sin ### er sprach vil liebiv swester daz sol sin getan ### als wir chomen widere wir han ze riten wan
###### 1150 | ### Der chunic unt sine mage rvmten do daz lant ### mit in die besten drunder die man inder vant ### niwan aleine Hagene der beleip da durch den haz ### den er trvoch der frowen vn– tet vil willechliche daz
| ### Die herren sworen eide vnz si moehten leben ### daz si den schazt niht <zeigen> noch niemen solden geben ### wan mit gemeinem rate so si des duhte gvot ### des mvsen si in vliesen durch ir giteklichen mvot
###### 1152 | ### E daz die chumige widere ze Rine wæren chomen ### die wile hete Hagene den grozen hort genomen ### er sancten da zem loche allen in den Rin ### er wande in niezen eine des enchunde sider niht gesin
###### 1153 | ### Erne mohte des hordes sit gewinnen niht ### daz den ungetriwen vil dicche noch geschiht ### er wande in niezen eine die wil er moehte lebn ### sit moht ers im selben noch ander nieman gegebn
| ### Die fvrsten chomen widere mit in vil manic man ### Chriemh' ir schaden grozen chlagen do began ### mit meiden vn– mit frowen in was harte leit ### do gebarten die degene sam si im heten widerseit
###### 1155 | ### Do sprachen si gemeine er hat vbele getan ### er entweich der fversten zorne also lange dan ### vnz er gewan ir hulde si <liezen> in genesn ### doch enchunde im Chriemh' nimmer vinder gewesn
###### 1156 | ### Mit iteniwem leide beswæret <was> ir mvot ### vmhe ir mannes ende un– do si ir daz gvot ### also gar genamen do gestunt ir iamers chlage ### des libes immer mere vnz an ir iungeste tage
###### 1157 | ### Nach Sivrides tode daz ist al war ### was si in manigen leiden vnz in daz zwelfte iar ### daz si des rechen todes mit chlage nie vergaz ### si was triwen stæte vn– tet vil willechliche daz
| ### Eine riche fursten aptey stifte vroe Vote ### nach Danchrates tode von ir gvote ### mit starchen richen vrborn als ez noch hivte hat ### daz kloster da ze Lorse des dinch vil hohe an eren stat
###### 1159 | ### Dar zvo gab ovch Chriemh' sit ein michel teil ### durch Sivrides sele vn– vmb aller sele heil ### golt un– edel steine mit williger hant ### getriwer wip decheine ist uns selten ê bechant
###### 1160 | ### Sit daz div frowe Chriemh' vof Gunther verchos ### vn– doch von sinen schuden den grozen hort verlos ### do wart ir hercen leide tusint stvnde mer ### do ware gerne dannen diu frowe edel vn– her [44v]
###### 1161 | ### Do was der frowen Voten ein sedelhof bereit ### ze Lorse bi ir chloster mit grozer richeite ### dar zoch sich div witewe von ir chinden sit ### da noch div frowe here begrabn in eime sarche lit
| ### Do sprach div kuniginne vil liebiv tohter min ### sit dv hie niht maht beliben so soltv bi mir sin ### ze Lorse in mime hvose vn– solt din weinen lan ### des antwrt ir Chriemh' wem liez ich danne minen man
###### 1163 | ### Den laz et hie beliben sprach froe Vote ### nvne welle got von himele sprach aber div gvot ### min vil liebiv mvoter daz sol ich wol bewarn ### wander mvoz fon hinnen mit mir wærliche varn
###### 1164 | ### Do schvof div iamers riche daz er wart vof erhabn ### sin edelez gebeine wart ander stvnt begrabn ### ze Lorse bi dem munster vil werdechlichen sit ### da der helt vil chuone in eime langen sarche lit
###### 1165 | ### In den selben ziten do Chriemh' solde ### varn mit ir mvter dar si doch wolde ### do mvste si beliben als ez solde sin ### daz understvnden mære vil verre chomen vber Rin

<<< Übersicht <<< vorige Seite nächste Seite >>>